::: ropt.ensemble_evaluator

::: ropt.evaluator
    options:
        members:
        - Evaluator
        - EvaluatorContext
        - EvaluatorResult
        - ConcurrentEvaluator
        - ConcurrentTask
